sandbox

package
v0.11.10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsScratchPath

func IsScratchPath(relPath string) bool

IsScratchPath returns true if relPath targets a scratch file or directory. Scratch paths are blocked for write operations to prevent the model from creating standalone exploration programs instead of writing proper tests.

Blocked patterns:

  • tmp/ directory and anything under it
  • tmp_*.go files at any level (standalone scratch programs)

func Resolve

func Resolve(root, relPath string) (string, error)

Resolve resolves relPath relative to root, returning the absolute path. It returns an error if relPath is empty, is absolute, or escapes root via traversal.

Types

This section is empty.

Jump to