verify

package
v0.11.10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package verify provides functions to run go test, go build, and go vet commands with output parsing capabilities.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Result

type Result struct {
	Command string
	Success bool
	Stdout  string
	Stderr  string
	Errors  []string
}

Result holds the outcome of a verification command execution.

func RunAll

func RunAll(dir string) ([]*Result, error)

RunAll runs test, build, and vet commands and returns all results.

func RunBuild

func RunBuild(dir string) (*Result, error)

RunBuild runs 'go build' in the specified directory and returns the result.

func RunTest

func RunTest(dir string) (*Result, error)

RunTest runs 'go test' in the specified directory and returns the result.

func RunVet

func RunVet(dir string) (*Result, error)

RunVet runs 'go vet' in the specified directory and returns the result.

Jump to